import fileinput
import re
import sys
from typing import List

__version__ = '1.2.0'

RESULT_REGEX = re.compile(
    r'Found (?P<count>\d+) errors'
)
REPLACES = {
    ord('<'): '&lt;',
    ord('"'): '&quot;',
}


def process_lines(lines: List[str]) -> str:
    result = {'count': 0, 'total_files': 0}
    failures = []
    output = ''

    for line in lines:
        if line.startswith('Found '):
            result = re.match(
                RESULT_REGEX,
                line
            ).groupdict()
            continue

        file_, line, type_, *msg = line.split(':')
        type_ = type_.strip()

        if type_ == 'error':
            failures.append((file_, line, type_, msg))

    output += f"""<?xml version="1.0" encoding="utf-8"?>
<testsuite errors="0" failures="{result['count']}" name="" skips="0" tests="{result['count']}" time="0.0">"""

    for failure in failures:
        msg = f"{failure[0]}:{failure[1]}: {failure[2]}: "
        msg += ':'.join(failure[3]).strip().translate(REPLACES)
        output += f"""
    <testcase name="{failure[0]}:{failure[1]}" time="0.0">
        <failure message="Mypy error on {failure[0]}:{failure[1]}" type="WARNING">{msg}</failure>
    </testcase>"""

    output += """
</testsuite>"""

    return output


def main():
    print(
        process_lines(
            list(fileinput.input())
        )
    )


if __name__ == "__main__":
    main()



import re

from setuptools import find_packages
from setuptools import setup


with open("mypy2junit.py", "rt", encoding="utf8") as f:
    version = re.search(r'__version__ = \'(.*?)\'', f.read()).group(1)

with open("README.md", "rt", encoding="utf8") as f:
    readme = f.read()

setup(
    name="mypy2junit",
    version=version,
    url="https://github.com/Dundee/mypy2junit",
    license="BSD-3-Clause",
    author="Daniel Milde",
    author_email="daniel@milde.cz",
    description="Script for converting output from MyPy to Junit XML format",
    long_description=readme,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
    ],
    #packages=find_packages("mypy2junit"),
    py_modules=["mypy2junit"],
    python_requires=">=3.5",
    entry_points={"console_scripts": ["mypy2junit = mypy2junit:main"]},
    extras_require={
        "dev": [
            "pytest",
        ],
    },
)
